# napari-webcam

[![License](https://img.shields.io/pypi/l/napari-webcam.svg?color=green)](https://github.com/haesleinhuepf/napari-webcam/raw/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/napari-webcam.svg?color=green)](https://pypi.org/project/napari-webcam)
[![Python Version](https://img.shields.io/pypi/pyversions/napari-webcam.svg?color=green)](https://python.org)
[![tests](https://github.com/haesleinhuepf/napari-webcam/workflows/tests/badge.svg)](https://github.com/haesleinhuepf/napari-webcam/actions)
[![codecov](https://codecov.io/gh/haesleinhuepf/napari-webcam/branch/master/graph/badge.svg)](https://codecov.io/gh/haesleinhuepf/napari-webcam)

Use your webcam from within napari!

----------------------------------

This [napari] plugin was generated with [Cookiecutter] using with [@napari]'s [cookiecutter-napari-plugin] template.

## Installation

You can install `napari-webcam` via [pip]:

    pip install napari-webcam

## Contributing

Contributions are very welcome. Tests can be run with [tox], please ensure
the coverage at least stays the same before you submit a pull request.

## License

Distributed under the terms of the [BSD-3] license,
"napari-webcam" is free and open source software

## Issues

If you encounter any problems, please open a thread on [image.sc] along with a detailed description.

[napari]: https://github.com/napari/napari
[Cookiecutter]: https://github.com/audreyr/cookiecutter
[@napari]: https://github.com/napari
[MIT]: http://opensource.org/licenses/MIT
[BSD-3]: http://opensource.org/licenses/BSD-3-Clause
[GNU GPL v3.0]: http://www.gnu.org/licenses/gpl-3.0.txt
[GNU LGPL v3.0]: http://www.gnu.org/licenses/lgpl-3.0.txt
[Apache Software License 2.0]: http://www.apache.org/licenses/LICENSE-2.0
[Mozilla Public License 2.0]: https://www.mozilla.org/media/MPL/2.0/index.txt
[cookiecutter-napari-plugin]: https://github.com/napari/cookiecutter-napari-plugin
[image.sc]: https://image.sc
[napari]: https://github.com/napari/napari
[tox]: https://tox.readthedocs.io/en/latest/
[pip]: https://pypi.org/project/pip/
[PyPI]: https://pypi.org/
